package gsauln.decisiontree.trainingsetgenerators;

import gsauln.MathUtils;
import gsauln.decisiontree.interfaces.IPoint;
import gsauln.decisiontree.interfaces.ITrainingPoint;
import gsauln.decisiontree.interfaces.ITrainingSetGenerator;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

/**
 * A training set generator that creates a bootstrap sample of an original training set at each query.
 * @author afrechet
 *
 * @param <TP> Type of training points used during the creation of the trees.
 * @param <P> Type of point used with the decision tree during query.
 */
public class BootstrapSampleTrainingSetGenerator<TP extends ITrainingPoint<P, ?>,P extends IPoint<?, ?>> implements ITrainingSetGenerator<ArrayList<TP>,TP,P>{
	
	private final List<TP> fTrainingSet;
	private final int fTrainingSampleSize;
	private final long fSeed;
	
	/**
	 * Construct a bootstrap sample training set generator.
	 * @param trainingSet - the original set to take bootstrap samples from.
	 * @param trainingsampleSize - the size of bootstrap samples to return.
	 * @param seed - the (partial) seed to use when generating new bootstrap samples.
	 */
	public BootstrapSampleTrainingSetGenerator(List<TP> trainingSet, int trainingsampleSize, long seed)
	{
		fTrainingSet = trainingSet;
		fTrainingSampleSize = trainingsampleSize;
		fSeed = seed;
	}

	@Override
	public ArrayList<TP> getTrainingSetAt(int index) {
		return MathUtils.getBoostrapSample(fTrainingSet, fTrainingSampleSize, new Random(fSeed*index));
	}
	
	
	
}
