/*
 *   Copyright 2011 Guillaume Saulnier-Comte
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package jparfor;

/**
 * Creates a functor (function object).
 * 
 * A functor is an object that will compute a function on a given input and return a result.
 *
 * @param <I> Type of input to compute the result for.
 * @param <R> Type of result to compute on the input.
 */
public interface Functor<I, R>
{

	/**
	 * Return the results computed over the input.
	 * @param input input to compute the results for.
	 * @return the results computed over the input.
	 */
	R function(I input);
	
}
