/*
 *   Copyright 2011 Guillaume Saulnier-Comte
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package jparfor;

/**
 * Class used by the MultiThreader.
 * Class used to index the results to return them in the same order that they were indexed.
 * @param <R> Type of result the object will contain.
 */
public class IndexedResult<R> implements Comparable<IndexedResult<R>>
{
	private int fIndex;
	private R fResult;
	
	/**
	 * Create the object with the given index and result.
	 * @param index index of the result.
	 * @param result result to be returned.
	 */
	public IndexedResult(int index, R result)
	{
		fIndex = index;
		fResult = result;
	}
	
	/**
	 * Return the index.
	 * @return the index.
	 */
	public int getIndex()
	{
		return fIndex;
	}
	
	/**
	 * Return the result.
	 * @return the result.
	 */
	public R getResult()
	{
		return fResult;
	}

	@Override
	public int compareTo(IndexedResult<R> o)
	{
		if (fIndex < o.getIndex())
		{
			return -1;
		}
		else if (fIndex > o.getIndex())
		{
			return 1;
		}
		else
		{
			return 0;
		}
	}
}
